package com.cj.jiaqingjiayi.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

import com.cj.jiaqingjiayi.common.ErrorCode;
import com.cj.jiaqingjiayi.exception.BusinessException;
import com.cj.jiaqingjiayi.exception.ThrowUtils;
import com.cj.jiaqingjiayi.mapper.OrderItemsMapper;
import com.cj.jiaqingjiayi.model.domain.Commodities;
import com.cj.jiaqingjiayi.model.domain.OrderItems;
import com.cj.jiaqingjiayi.service.CommoditiesService;
import com.cj.jiaqingjiayi.service.OrderItemsService;
import org.apache.commons.lang3.ObjectUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;

/**
* @author 高木
* @description 针对表【order_items(详细订单表)】的数据库操作Service实现
* @createDate 2024-11-10 14:25:15
*/
@Service
public class OrderItemsServiceImpl extends ServiceImpl<OrderItemsMapper, OrderItems>
    implements OrderItemsService {

    @Resource
    private CommoditiesService commoditiesService;

    @Override
    public void validOrderItems(OrderItems orderItems) {
        Long commoditiesId = orderItems.getCommoditiesId();
        Integer quantity = orderItems.getQuantity();
        BigDecimal price = orderItems.getPrice();
        // 校验菜品是否存在
        Commodities commodities = commoditiesService.getById(commoditiesId);
        ThrowUtils.throwIf(commodities == null, ErrorCode.NOT_FOUND_ERROR, "商品不存在");
        // 有参数则校验
        if (ObjectUtils.allNotNull(commoditiesId, quantity, price)) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "商品错误");
        }
    }
}




