package com.cj.jiaqingjiayi.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

import com.cj.jiaqingjiayi.common.ErrorCode;
import com.cj.jiaqingjiayi.exception.BusinessException;
import com.cj.jiaqingjiayi.model.domain.OrderItems;
import com.cj.jiaqingjiayi.model.domain.Orders;
import com.cj.jiaqingjiayi.service.OrderItemsService;
import com.cj.jiaqingjiayi.service.OrdersService;
import com.cj.jiaqingjiayi.mapper.OrdersMapper;
import com.cj.jiaqingjiayi.utils.RegexUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import javax.naming.Name;
import java.math.BigDecimal;
import java.util.List;
import java.util.Random;

/**
* @author 高木
* @description 针对表【orders(订单表)】的数据库操作Service实现
* @createDate 2024-11-10 14:22:10
*/
@Service
public class OrdersServiceImpl extends ServiceImpl<OrdersMapper, Orders>
    implements OrdersService{

    @Resource
    private OrderItemsService orderItemsService;

    @Transactional(rollbackFor = Exception.class)
    @Override
    public long addOrder(Orders orders, List<OrderItems> orderItemsList) {
        // 获取当前时间的秒级时间戳（去掉年、月、日的前缀）
        String timePart = String.valueOf(System.currentTimeMillis() / 1000).substring(4);
        // 生成两位随机数
        String randomPart = String.format("%02d", new Random().nextInt(100));
        String orderNumber = timePart + randomPart;
        //设置订单号
        orders.setOrderNumber(orderNumber);

        boolean saveOrder = this.save(orders);
        if (!saveOrder) {
            throw new BusinessException(ErrorCode.SYSTEM_ERROR, "创建订单失败，数据库错误");
        }
        // 创建订单商品
        for (OrderItems orderItems : orderItemsList) {
            // 绑定订单和订单详情
            orderItems.setOrderId(orders.getId());
            boolean saveItems = orderItemsService.save(orderItems);
            if (!saveItems) {
                log.error("创建订单商品失败，订单id：" + orders.getId());
                throw new BusinessException(ErrorCode.OPERATION_ERROR, "订单商品创建失败");
            }
        }
        return orders.getId();
    }

    @Override
    public void validOrder(Orders orders) {
        String userName = orders.getUserName();
        String phone = orders.getPhone();
        Long userId = orders.getUserId();
        Long businessId = orders.getBusinessId();
        BigDecimal totalPrice = orders.getTotalPrice();
        Integer payMethod = orders.getPayMethod();
        if (StringUtils.isAnyBlank(userName, phone)) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        if (StringUtils.isNotBlank(phone) && RegexUtils.isPhoneInvalid(phone)) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "手机号格式错误");
        }
        if (ObjectUtils.isEmpty(totalPrice) || totalPrice.floatValue() <= 0) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "价格错误");
        }
        if (ObjectUtils.anyNull(userId, businessId, payMethod)) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "参数不全");
        }
    }
}




